@@ -17,16 +17,17 @@
 
 #include <KItinerary/ExtractorEngine>
 #include <KItinerary/ExtractorPostprocessor>
-#include <KItinerary/ExtractorPreprocessor>
-#include <KItinerary/ExtractorRepository>
+#include <KItinerary/HtmlDocument>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/PdfDocument>
-#include <KItinerary/StructuredDataExtractor>
 
 #include <KPkPass/Pass>
 
 #include <KMime/Message>
 
+#include <KCalCore/MemoryCalendar>
+#include <KCalCore/ICalFormat>
+
 #include <QDebug>
 #include <QDir>
 #include <QDirIterator>
@@ -50,7 +51,6 @@ class ExtractorTest : public QObject
     Q_OBJECT
 private:
     ExtractorEngine m_engine;
-    ExtractorRepository m_repo;
 
 private Q_SLOTS:
     void initTestCase()
@@ -64,30 +64,24 @@ private Q_SLOTS:
         QTest::addColumn<QString>("contextFile");
         QTest::addColumn<QString>("inputFile");
 
-        QDir baseDir(QStringLiteral(SOURCE_DIR "/../../kitinerary-tests"));
-        // test data not available: add dummy entry to not fail the test
-        if (!baseDir.exists()) {
-            QTest::newRow("test data not available") << QString() << QString();
-            return;
-        }
+        for (const QDir &baseDir :  {QStringLiteral(SOURCE_DIR "/extractordata"), QStringLiteral(SOURCE_DIR "/../../kitinerary-tests")}) {
+            if (!baseDir.exists()) {
+                continue;
+            }
 
-        bool someTestsFound = false;
+            QDirIterator it(baseDir.path(), {QStringLiteral("*.txt"), QStringLiteral("*.html"), QStringLiteral("*.pdf"), QStringLiteral("*.pkpass"), QStringLiteral("*.ics"), QStringLiteral("*.eml"), QStringLiteral("*.mbox")}, QDir::Files | QDir::Readable | QDir::NoSymLinks, QDirIterator::Subdirectories);
+            while (it.hasNext()) {
+                it.next();
+                // ignore context files
+                if (it.fileName() == QLatin1String("context.eml")) {
+                    continue;
+                }
 
-        QDirIterator dirIt(baseDir.path(), {QStringLiteral("context.eml")}, QDir::Files | QDir::Readable | QDir::NoSymLinks, QDirIterator::Subdirectories);
-        while (dirIt.hasNext()) {
-            QFileInfo contextFi(dirIt.next());
-            QDirIterator fileIt(contextFi.absolutePath(), {QStringLiteral("*.txt"), QStringLiteral("*.html"), QStringLiteral("*.pdf"), QStringLiteral("*.pkpass")}, QDir::Files | QDir::Readable | QDir::NoSymLinks);
-            while (fileIt.hasNext()) {
-                fileIt.next();
-                someTestsFound = true;
-                QTest::newRow((contextFi.dir().dirName() + QLatin1Char('-') + fileIt.fileName()).toLatin1().constData())
+                QFileInfo contextFi(it.fileInfo().absolutePath() + QLatin1String("/context.eml"));
+                QTest::newRow((contextFi.dir().dirName() + QLatin1Char('-') + it.fileName()).toLatin1().constData())
                     << contextFi.absoluteFilePath()
-                    << fileIt.fileInfo().absoluteFilePath();
+                    << it.fileInfo().absoluteFilePath();
             }
-        }
-        if (!someTestsFound) {
-            QTest::newRow("no tests found in test dir") << QString() << QString();
-            return;
         }
     }
 
@@ -102,54 +96,56 @@ private Q_SLOTS:
         m_engine.clear();
 
         QFile cf(contextFile);
-        QVERIFY(cf.open(QFile::ReadOnly));
         KMime::Message contextMsg;
-        contextMsg.setContent(cf.readAll());
-        contextMsg.parse();
-        m_engine.setSenderDate(contextMsg.date()->dateTime());
+        if (cf.open(QFile::ReadOnly)) {
+            contextMsg.setContent(cf.readAll());
+            contextMsg.parse();
+            m_engine.setContext(&contextMsg);
+        }
 
         QFile inFile(inputFile);
         QVERIFY(inFile.open(QFile::ReadOnly));
 
         std::unique_ptr<KPkPass::Pass> pass;
+        std::unique_ptr<HtmlDocument> htmlDoc;
         std::unique_ptr<PdfDocument> pdfDoc;
-        std::vector<const Extractor*> extractors = m_repo.extractorsForMessage(&contextMsg);
+        KCalCore::Calendar::Ptr calendar;
+        std::unique_ptr<KMime::Message> mimeMsg;
         QJsonArray jsonResult;
 
         if (inputFile.endsWith(QLatin1String(".pkpass"))) {
             pass.reset(KPkPass::Pass::fromData(inFile.readAll()));
-            extractors = m_repo.extractorsForPass(pass.get());
             m_engine.setPass(pass.get());
         } else if (inputFile.endsWith(QLatin1String(".pdf"))) {
             pdfDoc.reset(PdfDocument::fromData(inFile.readAll()));
             QVERIFY(pdfDoc);
             m_engine.setPdfDocument(pdfDoc.get());
         } else if (inputFile.endsWith(QLatin1String(".html"))) {
-            const auto html = QString::fromUtf8(inFile.readAll());
-            StructuredDataExtractor se;
-            se.parse(html);
-            jsonResult = se.data();
-
-            ExtractorPreprocessor preproc;
-            preproc.preprocessHtml(html);
-            m_engine.setText(preproc.text());
+            htmlDoc.reset(HtmlDocument::fromData(inFile.readAll()));
+            QVERIFY(htmlDoc);
+            m_engine.setHtmlDocument(htmlDoc.get());
         } else if (inputFile.endsWith(QLatin1String(".txt"))) {
             m_engine.setText(QString::fromUtf8(inFile.readAll()));
+        } else if (inputFile.endsWith(QLatin1String(".ics"))) {
+            calendar.reset(new KCalCore::MemoryCalendar(QTimeZone()));
+            KCalCore::ICalFormat format;
+            QVERIFY(format.fromRawString(calendar, inFile.readAll()));
+            m_engine.setCalendar(calendar);
+        } else if (inputFile.endsWith(QLatin1String(".eml")) || inputFile.endsWith(QLatin1String(".mbox"))) {
+            mimeMsg.reset(new KMime::Message);
+            mimeMsg->setContent(inFile.readAll());
+            mimeMsg->parse();
+            m_engine.setContent(mimeMsg.get());
         }
 
-        for (const auto &extractor : extractors) {
-            if (!jsonResult.isEmpty()) {
-                break;
-            }
-            m_engine.setExtractor(extractor);
-            jsonResult = m_engine.extract();
-        }
+        jsonResult = m_engine.extract();
 
         const auto expectedSkip = QFile::exists(inputFile + QLatin1String(".skip"));
         if (jsonResult.isEmpty() && expectedSkip) {
             QSKIP("nothing extracted");
             return;
         }
+        QVERIFY(!jsonResult.isEmpty());
         const auto result = JsonLdDocument::fromJson(jsonResult);
         ExtractorPostprocessor postproc;
         postproc.setContextDate(contextMsg.date()->dateTime());
