@@ -22,12 +22,16 @@
 #include "logging.h"
 
 #include <KItinerary/Action>
+#include <KItinerary/Brand>
 #include <KItinerary/BusTrip>
+#include <KItinerary/Event>
 #include <KItinerary/Flight>
 #include <KItinerary/Organization>
 #include <KItinerary/Person>
 #include <KItinerary/Place>
 #include <KItinerary/Reservation>
+#include <KItinerary/RentalCar>
+#include <KItinerary/Taxi>
 #include <KItinerary/Ticket>
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
@@ -94,8 +98,9 @@ static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
     case QVariant::Double:
         return doubleValue(v);
     case QVariant::Int:
-        if (v.isDouble())
+        if (v.isDouble()) {
             return v.toDouble();
+        }
         return v.toString().toInt();
     case QVariant::Url:
         return QUrl(v.toString());
@@ -159,16 +164,21 @@ static QVariant createInstance(const QJsonObject &obj)
     MAKE_FACTORY(Action);
     MAKE_FACTORY(Airline);
     MAKE_FACTORY(Airport);
+    MAKE_FACTORY(Brand);
     MAKE_FACTORY(BusReservation);
     MAKE_FACTORY(BusStation);
     MAKE_FACTORY(BusTrip);
     MAKE_FACTORY(CancelAction);
     MAKE_FACTORY(CheckInAction);
     MAKE_FACTORY(DownloadAction);
+    MAKE_FACTORY(Event);
+    MAKE_FACTORY(EventReservation);
     MAKE_FACTORY(Flight);
     MAKE_FACTORY(FlightReservation);
     MAKE_FACTORY(FoodEstablishment);
     MAKE_FACTORY(FoodEstablishmentReservation);
+    MAKE_FACTORY(RentalCarReservation);
+    MAKE_FACTORY(RentalCar);
     MAKE_FACTORY(GeoCoordinates);
     MAKE_FACTORY(LodgingBusiness);
     MAKE_FACTORY(LodgingReservation);
@@ -177,6 +187,8 @@ static QVariant createInstance(const QJsonObject &obj)
     MAKE_FACTORY(Place);
     MAKE_FACTORY(PostalAddress);
     MAKE_FACTORY(Seat);
+    MAKE_FACTORY(TaxiReservation);
+    MAKE_FACTORY(Taxi);
     MAKE_FACTORY(Ticket);
     MAKE_FACTORY(TouristAttraction);
     MAKE_FACTORY(TouristAttractionVisit);
@@ -184,7 +196,7 @@ static QVariant createInstance(const QJsonObject &obj)
     MAKE_FACTORY(TrainStation);
     MAKE_FACTORY(TrainTrip);
     MAKE_FACTORY(UpdateAction);
-    MAKE_FACTORY(ViewAction);
+    MAKE_FACTORY(ViewAction);    
     return {};
 }
 
@@ -214,6 +226,19 @@ static bool valueIsNull(const QVariant &v)
     return v.isNull();
 }
 
+static QString typeName(const QMetaObject *mo, const QVariant &v)
+{
+    const auto n = JsonLdDocument::readProperty(v, "className").toString();
+    if (!n.isEmpty()) {
+        return n;
+    }
+
+    if (auto c = strstr(mo->className(), "::")) {
+        return QString::fromUtf8(c + 2);
+    }
+    return QString::fromUtf8(mo->className());
+}
+
 static QJsonValue toJson(const QVariant &v)
 {
     const auto mo = QMetaType(v.userType()).metaObject();
@@ -242,6 +267,8 @@ static QJsonValue toJson(const QVariant &v)
         }
         case QVariant::Url:
             return v.toUrl().toString();
+        case QVariant::Bool:
+            return v.toBool();
         default:
             break;
         }
@@ -267,7 +294,7 @@ static QJsonValue toJson(const QVariant &v)
 
     // composite types
     QJsonObject obj;
-    obj.insert(QStringLiteral("@type"), JsonLdDocument::readProperty(v, "className").toString());
+    obj.insert(QStringLiteral("@type"), typeName(mo, v));
     for (int i = 0; i < mo->propertyCount(); ++i) {
         const auto prop = mo->property(i);
         if (!prop.isStored()) {
